pub fn set_panic_hook()Expand description
Re-export panic hook setup.
Set the console.error panic hook the first time this is called. Subsequent
invocations do nothing.
pub fn set_panic_hook()Re-export panic hook setup.
Set the console.error panic hook the first time this is called. Subsequent
invocations do nothing.